:mod:`art.detection`
====================
.. automodule:: art.detection

Base Class
----------
.. autoclass:: Detector
   :members:
   :special-members:

Binary Input Detector
---------------------
.. autoclass:: BinaryInputDetector
   :members:
   :special-members:

BinaryActivationDetector
------------------------
.. autoclass:: BinaryActivationDetector
   :members:
   :special-members:
